@@ -44,7 +44,7 @@ class SyncTitle(Fixup):
 
           verbose (bool): Verbose flag from command line.
 
-          config (dict): The entire config file.
+          config (ConfigFile): The config file.
 
           fixup_kwargs (dict): The kwargs config parameter for the fixup,
             with the following items:
@@ -63,7 +63,7 @@ class SyncTitle(Fixup):
               the configured types. Optional, default is None.
         """
 
-        path_mappings = config.get('path_mappings', [])
+        path_mappings = config.data.get('path_mappings', [])
 
         section_types = fixup_kwargs.get('section_types', None)
         section_pattern = fixup_kwargs.get('section_pattern', None)
@@ -95,14 +95,13 @@ class SyncTitle(Fixup):
             if section_pattern is not None and \
                     re.search(section_pattern, section.title) is None:
                 if verbose:
-                    print("Skipping {s.type} library section {s.title!r} "
+                    print("Skipping {s.type} section {s.title!r} "
                           "that does not match the specified pattern".
                           format(s=section))
                     sys.stdout.flush()
                 continue
 
-            print("Processing library section of type {s.type}: "
-                  "{s.title!r}".
+            print("Processing {s.type} section {s.title!r}".
                   format(s=section))
             sys.stdout.flush()
 
@@ -111,8 +110,8 @@ class SyncTitle(Fixup):
                     items = section.all()
             except (plexapi.exceptions.PlexApiException,
                     requests.exceptions.RequestException) as exc:
-                print("Error: Cannot list all items in section of type "
-                      "{s.type}: {s.title!r}: {msg} ({w.debug_str})".
+                print("Error: Cannot list all items in {s.type} section "
+                      "{s.title!r}: {msg} ({w.debug_str})".
                       format(s=section, msg=exc, w=w))
                 return 1
 
@@ -141,7 +140,7 @@ class SyncTitle(Fixup):
                             return rc
                 else:
                     print("Error: Invalid section type {type!r} encountered in "
-                          "library section {s.title!r}".
+                          "section {s.title!r}".
                           format(type=item.type, s=section))
                     return 1
 
@@ -202,7 +201,7 @@ def get_title_tag(media_file):
     ffprobe = ffmpy.FFprobe(
         global_options=['-hide_banner', '-show_format',
                         '-of', 'json=sv=ignore'],
-        inputs={media_file_b: None})
+        inputs={media_file: None})
 
     try:
         stdout, stderr = ffprobe.run(
